==> istio-model-v1beta1-6.8.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/HTTPFaultInjectionDelayFixedDelayFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPFaultInjectionDelayFixedDelayFluent<A extends HTTPFaultInjectionDelayFixedDelayFluent<A>> extends BaseFluent<A>{
  public HTTPFaultInjectionDelayFixedDelayFluent() {
  }
  public HTTPFaultInjectionDelayFixedDelayFluent(HTTPFaultInjectionDelayFixedDelay instance) {
    instance = (instance != null ? instance : new HTTPFaultInjectionDelayFixedDelay());

    if (instance != null) {
      this.withFixedDelay(instance.getFixedDelay());
      this.withFixedDelay(instance.getFixedDelay());
    }
  }
  private String fixedDelay;
  public String getFixedDelay() {
    return this.fixedDelay;
  }
  public A withFixedDelay(String fixedDelay) {
    this.fixedDelay=fixedDelay; return (A) this;
  }
  public boolean hasFixedDelay() {
    return this.fixedDelay != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPFaultInjectionDelayFixedDelayFluent that = (HTTPFaultInjectionDelayFixedDelayFluent) o;
    if (!java.util.Objects.equals(fixedDelay, that.fixedDelay)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fixedDelay,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (fixedDelay != null) { sb.append("fixedDelay:"); sb.append(fixedDelay); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1beta1-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/HTTPFaultInjectionDelayFixedDelayFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class HTTPFaultInjectionDelayFixedDelayFluent<A extends HTTPFaultInjectionDelayFixedDelayFluent<A>> extends BaseFluent<A>{
  public HTTPFaultInjectionDelayFixedDelayFluent() {
  }
  
  public HTTPFaultInjectionDelayFixedDelayFluent(HTTPFaultInjectionDelayFixedDelay instance) {
    this.copyInstance(instance);
  }
  private String fixedDelay;
  
  protected void copyInstance(HTTPFaultInjectionDelayFixedDelay instance) {
    instance = (instance != null ? instance : new HTTPFaultInjectionDelayFixedDelay());
  
    if (instance != null) {
        this.withFixedDelay(instance.getFixedDelay());
        this.withFixedDelay(instance.getFixedDelay());
      }
  }
  
  public String getFixedDelay() {
    return this.fixedDelay;
  }
  
  public A withFixedDelay(String fixedDelay) {
    this.fixedDelay=fixedDelay; return (A) this;
  }
  
  public boolean hasFixedDelay() {
    return this.fixedDelay != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPFaultInjectionDelayFixedDelayFluent that = (HTTPFaultInjectionDelayFixedDelayFluent) o;
    if (!java.util.Objects.equals(fixedDelay, that.fixedDelay)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(fixedDelay,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (fixedDelay != null) { sb.append("fixedDelay:"); sb.append(fixedDelay); }
    sb.append("}");
    return sb.toString();
  }
  

}
